import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import cdktf._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@cdktf/tf-module-stack",
    "1.1.21",
    __name__[0:-6],
    "tf-module-stack@1.1.21.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
